==> icedtea-bin-src-3.6.0.tar.xz: sun/management/resources/agent_sv.java <==
package sun.management.resources;

import java.util.ListResourceBundle;

public final class agent_sv extends ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "agent.err.access.file.not.readable", "Access-filen \u00E4r inte l\u00E4sbar" },
            { "agent.err.access.file.notfound", "Access-filen hittades inte" },
            { "agent.err.access.file.notset", "\u00C5tkomstfilen har inte angetts men com.sun.management.jmxremote.authenticate=true" },
            { "agent.err.access.file.read.failed", "Kunde inte l\u00E4sa \u00E5tkomstfilen" },
            { "agent.err.acl.file.access.notrestricted", "L\u00E4sbeh\u00F6righeten f\u00F6r filen m\u00E5ste begr\u00E4nsas" },
            { "agent.err.acl.file.not.readable", "SNMP \u00E5tkomstkontrollista-filen \u00E4r inte l\u00E4sbar" },
            { "agent.err.acl.file.notfound", "SNMP \u00E5tkomstkontrollista-filen hittades inte" },
            { "agent.err.acl.file.notset", "Ingen SNMP \u00E5tkomstkontrollista-fil har angetts, men com.sun.management.snmp.acl=true" },
            { "agent.err.acl.file.read.failed", "Kunde inte l\u00E4sa filen SNMP \u00E5tkomstkontrollista" },
            { "agent.err.agentclass.access.denied", "\u00C5tkomst till premain(String) nekad" },
            { "agent.err.agentclass.failed", "Administrationsagentklassen utf\u00F6rdes inte " },
            { "agent.err.agentclass.notfound", "Administrationsagentklassen hittades inte" },
            { "agent.err.configfile.access.denied", "\u00C5tkomst till konfigurationsfilen nekad" },
            { "agent.err.configfile.closed.failed", "Kunde inte st\u00E4nga konfigurationsfilen" },
            { "agent.err.configfile.failed", "Kunde inte l\u00E4sa konfigurationsfilen" },
            { "agent.err.configfile.notfound", "Konfigurationsfilen hittades inte" },
            { "agent.err.connector.server.io.error", "Serverkommunikationsfel f\u00F6r JMX-anslutning" },
            { "agent.err.error", "Fel" },
            { "agent.err.exception", "Agenten orsakade ett undantag " },
            { "agent.err.exportaddress.failed", "Kunde inte exportera JMX-anslutningsadressen till instrumentbufferten" },
            { "agent.err.file.access.not.restricted", "Fill\u00E4snings\u00E5tkomst m\u00E5ste begr\u00E4nsas" },
            { "agent.err.file.not.found", "Filen hittades inte" },
            { "agent.err.file.not.readable", "Filen \u00E4r inte l\u00E4sbar" },
            { "agent.err.file.not.set", "Filen \u00E4r inte angiven" },
            { "agent.err.file.read.failed", "Kunde inte l\u00E4sa filen" },
            { "agent.err.invalid.agentclass", "Ogiltigt egenskapsv\u00E4rde f\u00F6r com.sun.management.agent.class" },
            { "agent.err.invalid.jmxremote.port", "Ogiltigt com.sun.management.jmxremote.port-nummer" },
            { "agent.err.invalid.jmxremote.rmi.port", "Ogiltigt com.sun.management.jmxremote.rmi.port-nummer" },
            { "agent.err.invalid.option", "Det angivna alternativet \u00E4r ogiltigt" },
            { "agent.err.invalid.snmp.port", "Ogiltigt com.sun.management.snmp.port-nummer" },
            { "agent.err.invalid.snmp.trap.port", "Ogiltigt com.sun.management.snmp.trap-nummer" },
            { "agent.err.invalid.state", "Ogiltigt agenttillst\u00E5nd" },
            { "agent.err.password.file.access.notrestricted", "L\u00E4sbeh\u00F6righeten f\u00F6r filen m\u00E5ste begr\u00E4nsas" },
            { "agent.err.password.file.not.readable", "L\u00F6senordsfilen \u00E4r inte l\u00E4sbar" },
            { "agent.err.password.file.notfound", "Hittar inte l\u00F6senordsfilen" },
            { "agent.err.password.file.notset", "L\u00F6senordsfilen har inte angetts men com.sun.management.jmxremote.authenticate=true" },
            { "agent.err.password.file.read.failed", "Kunde inte l\u00E4sa l\u00F6senordsfilen" },
            { "agent.err.premain.notfound", "premain(String) finns inte i agentklassen" },
            { "agent.err.snmp.adaptor.start.failed", "Kunde inte starta SNMP-adaptern med adressen" },
            { "agent.err.snmp.mib.init.failed", "Kunde inte initiera SNMP MIB. Returnerade felet" },
            { "agent.err.unknown.snmp.interface", "Ok\u00E4nt SNMP-gr\u00E4nssnitt" },
            { "agent.err.warning", "Varning" },
            { "jmxremote.AdaptorBootstrap.getTargetList.adding", "M\u00E5l l\u00E4ggs till: {0}" },
            { "jmxremote.AdaptorBootstrap.getTargetList.initialize1", "Adaptern redo." },
            { "jmxremote.AdaptorBootstrap.getTargetList.initialize2", "SNMP-adaptern redo p\u00E5: {0}:{1}" },
            { "jmxremote.AdaptorBootstrap.getTargetList.processing", "\u00E5tkomstkontrollista bearbetas" },
            { "jmxremote.AdaptorBootstrap.getTargetList.starting", "Adapterservern startas:" },
            { "jmxremote.AdaptorBootstrap.getTargetList.terminate", "avsluta {0}" },
            { "jmxremote.ConnectorBootstrap.file.readonly", "Fill\u00E4snings\u00E5tkomst m\u00E5ste begr\u00E4nsas {0}" },
            { "jmxremote.ConnectorBootstrap.noAuthentication", "Ingen autentisering" },
            { "jmxremote.ConnectorBootstrap.password.readonly", "L\u00E4sbeh\u00F6righeten f\u00F6r l\u00F6senordsfilen m\u00E5ste begr\u00E4nsas: {0}" },
            { "jmxremote.ConnectorBootstrap.ready", "JMX-anslutning redo p\u00E5: {0}" },
            { "jmxremote.ConnectorBootstrap.starting", "Startar server f\u00F6r JMX-anslutning:" },
        };
    }
}

==> icedtea-bin-src-7.2.5.6.tar.xz: sun/management/resources/agent_sv.java <==
package sun.management.resources;

import java.util.ListResourceBundle;

public final class agent_sv extends ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "agent.err.access.file.not.readable", "Access-filen \u00E4r inte l\u00E4sbar" },
            { "agent.err.access.file.notfound", "Access-filen hittades inte" },
            { "agent.err.access.file.notset", "\u00C5tkomstfilen har inte angetts men com.sun.management.jmxremote.authenticate=true" },
            { "agent.err.access.file.read.failed", "Kunde inte l\u00E4sa \u00E5tkomstfilen" },
            { "agent.err.acl.file.access.notrestricted", "L\u00E4sbeh\u00F6righeten f\u00F6r filen m\u00E5ste begr\u00E4nsas" },
            { "agent.err.acl.file.not.readable", "SNMP ACL-filen \u00E4r inte l\u00E4sbar" },
            { "agent.err.acl.file.notfound", "SNMP ACL-filen hittades inte" },
            { "agent.err.acl.file.notset", "Ingen SNMP ACL-fil har angetts, men com.sun.management.snmp.acl=true" },
            { "agent.err.acl.file.read.failed", "Kunde inte l\u00E4sa filen SNMP ACL" },
            { "agent.err.agentclass.access.denied", "\u00C5tkomst till premain(String) nekad" },
            { "agent.err.agentclass.failed", "Administrationsagentklassen utf\u00F6rdes inte " },
            { "agent.err.agentclass.notfound", "Administrationsagentklassen hittades inte" },
            { "agent.err.configfile.access.denied", "\u00C5tkomst till konfigurationsfilen nekad" },
            { "agent.err.configfile.closed.failed", "Kunde inte st\u00E4nga konfigurationsfilen" },
            { "agent.err.configfile.failed", "Kunde inte l\u00E4sa konfigurationsfilen" },
            { "agent.err.configfile.notfound", "Konfigurationsfilen hittades inte" },
            { "agent.err.connector.server.io.error", "Serverkommunikationsfel f\u00F6r JMX-anslutning" },
            { "agent.err.error", "Fel" },
            { "agent.err.exception", "Agenten orsakade ett undantag " },
            { "agent.err.exportaddress.failed", "Kunde inte exportera JMX-anslutningsadressen till instrumentbufferten" },
            { "agent.err.file.access.not.restricted", "Fill\u00E4snings\u00E5tkomst m\u00E5ste begr\u00E4nsas" },
            { "agent.err.file.not.found", "Filen hittades inte" },
            { "agent.err.file.not.readable", "Filen \u00E4r inte l\u00E4sbar" },
            { "agent.err.file.not.set", "Filen \u00E4r inte angiven" },
            { "agent.err.file.read.failed", "Kunde inte l\u00E4sa filen" },
            { "agent.err.invalid.agentclass", "Ogiltigt egenskapsv\u00E4rde f\u00F6r com.sun.management.agent.class" },
            { "agent.err.invalid.jmxremote.port", "Ogiltigt com.sun.management.jmxremote.port-nummer" },
            { "agent.err.invalid.jmxremote.rmi.port", "Ogiltigt com.sun.management.jmxremote.rmi.port-nummer" },
            { "agent.err.invalid.option", "Det angivna alternativet \u00E4r ogiltigt" },
            { "agent.err.invalid.snmp.port", "Ogiltigt com.sun.management.snmp.port-nummer" },
            { "agent.err.invalid.snmp.trap.port", "Ogiltigt com.sun.management.snmp.trap-nummer" },
            { "agent.err.invalid.state", "Ogiltig agentstatus" },
            { "agent.err.password.file.access.notrestricted", "L\u00E4sbeh\u00F6righeten f\u00F6r filen m\u00E5ste begr\u00E4nsas" },
            { "agent.err.password.file.not.readable", "L\u00F6senordsfilen \u00E4r inte l\u00E4sbar" },
            { "agent.err.password.file.notfound", "Hittar inte l\u00F6senordsfilen" },
            { "agent.err.password.file.notset", "L\u00F6senordsfilen har inte angetts men com.sun.management.jmxremote.authenticate=true" },
            { "agent.err.password.file.read.failed", "Kunde inte l\u00E4sa l\u00F6senordsfilen" },
            { "agent.err.premain.notfound", "premain(String) finns inte i agentklassen" },
            { "agent.err.snmp.adaptor.start.failed", "Kunde inte starta SNMP-adaptern med adressen" },
            { "agent.err.snmp.mib.init.failed", "Kunde inte initiera SNMP MIB. Returnerade felet" },
            { "agent.err.unknown.snmp.interface", "Ok\u00E4nt SNMP-gr\u00E4nssnitt" },
            { "agent.err.warning", "Varning" },
            { "jmxremote.AdaptorBootstrap.getTargetList.adding", "M\u00E5l l\u00E4ggs till: {0}" },
            { "jmxremote.AdaptorBootstrap.getTargetList.initialize1", "Adaptern redo." },
            { "jmxremote.AdaptorBootstrap.getTargetList.initialize2", "SNMP-adaptern redo p\u00E5: {0}:{1}" },
            { "jmxremote.AdaptorBootstrap.getTargetList.processing", "ACL bearbetas" },
            { "jmxremote.AdaptorBootstrap.getTargetList.starting", "Adapterservern startas:" },
            { "jmxremote.AdaptorBootstrap.getTargetList.terminate", "avsluta {0}" },
            { "jmxremote.ConnectorBootstrap.file.readonly", "Fill\u00E4snings\u00E5tkomst m\u00E5ste begr\u00E4nsas {0}" },
            { "jmxremote.ConnectorBootstrap.noAuthentication", "Ingen autentisering" },
            { "jmxremote.ConnectorBootstrap.password.readonly", "L\u00E4sbeh\u00F6righeten f\u00F6r l\u00F6senordsfilen m\u00E5ste begr\u00E4nsas: {0}" },
            { "jmxremote.ConnectorBootstrap.ready", "JMX-anslutning redo p\u00E5: {0}" },
            { "jmxremote.ConnectorBootstrap.starting", "Startar server f\u00F6r JMX-anslutning:" },
        };
    }
}
